API-package: This package gets connected with geocode API.

Description Details Author(s) References See Also Examples

Description

hi.

Details

The DESCRIPTION file: This package was not yet installed at build time.

Index: This package was not yet installed at build time.
~~ An overview of how to use the package, including the most important functions ~~

Author(s)

Mariano, Pedram & Roshni

Maintainer: <pedka102@student.liu.se>

References

~~ Literature or other references for background information ~~

See Also

~~ Optional links to other man pages, e.g. ~~ ~~ <pkg> ~~

Examples

1
~~ simple examples of the most important functions ~~

pedism/5 documentation built on May 8, 2019, 12:57 p.m.